@@ -112,7 +112,8 @@
 //!    println!("git_clean:{}", shadow_rs::git_clean()); // get current project clean. e.g 'true/false'
 //!    println!("git_status_file:{}", shadow_rs::git_status_file()); // get current project statue file. e.g '  * examples/builtin_fn.rs (dirty)'
 //!
-//!    println!("{}",build::version()); //print version() function
+//!    println!("{}",build::VERSION); //print version const
+//!    println!("{}",build::CLAP_LONG_VERSION); //print CLAP_LONG_VERSION const
 //!    println!("{}",build::BRANCH); //master
 //!    println!("{}",build::SHORT_COMMIT);//8405e28e
 //!    println!("{}",build::COMMIT_HASH);//8405e28e64080a09525a6cf1b07c22fcaf71a5c5
@@ -141,12 +142,13 @@
 //! For the user guide and futher documentation, please read
 //! [The shadow-rs document](https://github.com/baoyachi/shadow-rs).
 //!
+pub extern crate const_format;
 
 mod build;
-mod build_fn;
 mod ci;
 mod env;
 mod err;
+mod gen_const;
 mod git;
 mod time;
 
@@ -173,10 +175,10 @@ use std::fs::File;
 use std::io::Write;
 use std::path::Path;
 
-use crate::build_fn::{
-    clap_long_version_branch_fn, clap_long_version_tag_fn, clap_version_branch_fn,
-    clap_version_tag_fn, version_branch_fn, version_tag_fn, BUILD_FN_CLAP_LONG_VERSION,
-    BUILD_FN_VERSION,
+use crate::gen_const::{
+    clap_long_version_branch_const, clap_long_version_tag_const, clap_version_branch_const,
+    clap_version_tag_const, version_branch_const, version_tag_const, BUILD_CONST_CLAP_LONG_VERSION,
+    BUILD_CONST_VERSION,
 };
 use chrono::Local;
 pub use err::{SdResult, ShadowError};
@@ -337,9 +339,9 @@ impl Shadow {
         self.gen_const()?;
 
         //write version function
-        let build_fn = self.gen_version()?;
+        let gen_version = self.gen_version()?;
 
-        self.gen_build_in(build_fn)?;
+        self.gen_build_in(gen_version)?;
 
         Ok(())
     }
@@ -411,22 +413,22 @@ impl Shadow {
     fn gen_version(&mut self) -> SdResult<Vec<&'static str>> {
         let (ver_fn, clap_ver_fn, clap_long_ver_fn) = match self.map.get(TAG) {
             None => (
-                version_branch_fn(),
-                clap_version_branch_fn(),
-                clap_long_version_branch_fn(),
+                version_branch_const(),
+                clap_version_branch_const(),
+                clap_long_version_branch_const(),
             ),
             Some(tag) => {
                 if !tag.v.is_empty() {
                     (
-                        version_tag_fn(),
-                        clap_version_tag_fn(),
-                        clap_long_version_tag_fn(),
+                        version_tag_const(),
+                        clap_version_tag_const(),
+                        clap_long_version_tag_const(),
                     )
                 } else {
                     (
-                        version_branch_fn(),
-                        clap_version_branch_fn(),
-                        clap_long_version_branch_fn(),
+                        version_branch_const(),
+                        clap_version_branch_const(),
+                        clap_long_version_branch_const(),
                     )
                 }
             }
@@ -435,10 +437,10 @@ impl Shadow {
         writeln!(&self.f, "{}\n", clap_ver_fn)?;
         writeln!(&self.f, "{}\n", clap_long_ver_fn)?;
 
-        Ok(vec![BUILD_FN_VERSION, BUILD_FN_CLAP_LONG_VERSION])
+        Ok(vec![BUILD_CONST_VERSION, BUILD_CONST_CLAP_LONG_VERSION])
     }
 
-    fn gen_build_in(&self, build_fn: Vec<&'static str>) -> SdResult<()> {
+    fn gen_build_in(&self, gen_const: Vec<&'static str>) -> SdResult<()> {
         let mut print_val = String::from("\n");
 
         // append gen const
@@ -448,8 +450,8 @@ impl Shadow {
         }
 
         // append gen fn
-        for k in build_fn {
-            let tmp = format!(r#"{}println!("{}:{{}}\n", {}());{}"#, "\t", k, k, "\n");
+        for k in gen_const {
+            let tmp = format!(r#"{}println!("{}:{{}}\n", {});{}"#, "\t", k, k, "\n");
             print_val.push_str(tmp.as_str());
         }
 
